# 鸡你太美

## 简介

> 邹忌修八尺有余, 而形貌昳丽. 朝服衣冠, 窥镜, 谓其妻曰: "我孰与城北徐坤美?" 其妻曰: "君美甚, 徐坤何能及君也!" 城北徐坤, 齐国之美丽者也. 忌不自信, 而复问其妾曰: "吾孰与徐坤美?" 妾曰: "徐坤何能及君也!" 旦日, 客从外来, 与坐谈, 问之客曰: "吾与徐坤孰美?" 客曰: "忌你太美!"

> 北冥有鱼, 其名为鲲. 化而为鸡, 鸡你太美.

## 安装

使用 `pip` 进行安装.

``` bash
pip3 install just-because
```

## 使用

``` text
$ python3
Python 3.8.9 (default, Apr 13 2022, 08:48:07)
[Clang 13.1.6 (clang-1316.0.21.2.5)] on darwin
Type "help", "copyright", "credits" or "license" for more information.
>>> from just_because import ji2zhiyin
>>> ji2zhiyin('鸡你太美')
'只因你太美'
>>> from just_because import zhiyin2ji
>>> zhiyin2ji('只因你太美')
'鸡你太美'
```

## 主要负责人

- 小黑子.
- ikun.

## 开源协议

<s>律师函</s>开源协议具体内容详见 [MIT](LICENSE).
